#include "settings.h"
#include <string.h>

LOG_MODULE_REGISTER(settings_log, LOG_LEVEL_INF);

#define CONFIG_SETTINGS_SUBTREE "config"
#define CONFIG_SETTINGS_OFFSET_NAME       	CONFIG_SETTINGS_SUBTREE"/offset"
#define CONFIG_SETTINGS_SLOPE_NAME      	CONFIG_SETTINGS_SUBTREE"/slope"


/* Let's create a structure that we want to save */
struct calib_param_t {
    uint32_t offset;
    double slope;
};

struct calib_param_t my_params;

static int settings_handle_set(const char *name, size_t len,
                            settings_read_cb read_cb, void *cb_arg)
{
    const char *next;
    size_t name_len;
    int rc;

    name_len = settings_name_next(name, &next);

    if (!next) {
		if (!strncmp(name, "offset", name_len)) {
			rc = read_cb(cb_arg, &my_params.offset, sizeof(my_params.offset));
			return 0;
		}

		if (!strncmp(name, "slope", name_len)) {
			rc = read_cb(cb_arg, &my_params.slope, sizeof(my_params.slope));
			return 0;
		}
	}
	return -ENOENT;
}

SETTINGS_STATIC_HANDLER_DEFINE(my_settings, CONFIG_SETTINGS_SUBTREE, 
					NULL, settings_handle_set, NULL, NULL);

int flash_init(){
    int err = 0;
    err = settings_subsys_init();
	if (err){
		LOG_ERR("Error while initializing the subsys : err = %d", err);
		return -1;
	}
	// Loads the Whitelist for advertising + settings for param
	err = settings_load();
	if (err){
		LOG_ERR("Error while loading settings : err = %d", err);
		return -2;
	}
    return err;
}

/**
 * GETTERS + SETTERS
 */

uint32_t get_param_offset(void)
{
    uint32_t offset = my_params.offset;
	return offset;
}

int set_param_offset(uint32_t value)
{
	my_params.offset = value;
	int ret = settings_save_one(CONFIG_SETTINGS_OFFSET_NAME, &value, sizeof(value));
    return ret;
}

double get_param_slope(void)
{
    double slope = my_params.slope;
	return slope;
}

int set_param_slope(double value)
{
	my_params.slope = value;
	int ret = settings_save_one(CONFIG_SETTINGS_SLOPE_NAME, &value, sizeof(value));
    return ret;
}
